property :job_name, String, name_property: true

property :description, String, default: 'Generated by Chef'
property :display_name, String
property :properties, Hash, default: {}
property :scm, Hash, default: {}, callbacks: { 'scm can only contain one key/value' => proc { |v| v.length <= 1 } }
property :triggers, Hash, default: {}
property :builders, Hash, default: {}
property :publishers, Hash, default: {}
property :wrappers, Hash, default: {}

property :template, String, default: 'freestyle-config.xml.erb'
property :include_templates, Array, default: []
property :auto_create_folders, [true, false], default: true

action :create do
  folder_name = ::File.dirname(new_resource.job_name)
  if new_resource.auto_create_folders && !folder_name.eql?('.')
    folder_name = ::File.dirname(new_resource.job_name)
    chef_jenkins_folder folder_name
  end

  xml = "#{Chef::Config[:file_cache_path]}/#{new_resource.job_name}.xml"

  directory ::File.dirname(xml) do
    recursive true
  end

  declare_resource(:template, xml) do
    source new_resource.template
    variables(
      description: new_resource.description,
      display_name: new_resource.display_name,
      properties: new_resource.properties,
      scm: new_resource.scm,
      triggers: new_resource.triggers,
      builders: new_resource.builders,
      publishers: new_resource.publishers,
      wrappers: new_resource.wrappers,

      cookbook: new_resource.cookbook_name,
      include_templates: new_resource.include_templates
    )
    helpers(ChefJenkins::Helper)
    cookbook include_templates.include?(new_resource.template) ? new_resource.cookbook_name : 'chef_jenkins'
  end

  jenkins_job new_resource.job_name do
    config xml
  end
end

action :delete do
  jenkins_job new_resource.job_name do
    action :delete
  end
end

action_class.class_eval do
  include ChefJenkins::Helper
end
